@@ -5,7 +5,6 @@ from trytond.model import ModelView, ModelSQL, fields, Unique
 from trytond.cache import Cache
 from trytond.transaction import Transaction
 from trytond.pool import Pool, PoolMeta
-from trytond import backend
 from trytond.config import config
 
 __all__ = ['Employee', 'EmployeeCostPrice', 'price_digits']
@@ -14,8 +13,7 @@ price_digits = (16, config.getint(
         'timesheet_cost', 'price_decimal', default=4))
 
 
-class Employee:
-    __metaclass__ = PoolMeta
+class Employee(metaclass=PoolMeta):
     __name__ = 'company.employee'
     cost_price = fields.Function(fields.Numeric('Cost Price',
             digits=price_digits,
@@ -78,15 +76,6 @@ class EmployeeCostPrice(ModelSQL, ModelView):
         digits=price_digits, required=True, help="Hourly cost price")
     employee = fields.Many2One('company.employee', 'Employee')
 
-    @classmethod
-    def __register__(cls, module_name):
-        TableHandler = backend.get('TableHandler')
-        super(EmployeeCostPrice, cls).__register__(module_name)
-        table = TableHandler(cls, module_name)
-
-        # Migration from 2.8 drop date_cost_price_uniq
-        table.drop_constraint('date_cost_price_uniq')
-
     @classmethod
     def __setup__(cls):
         super(EmployeeCostPrice, cls).__setup__()
